<?php
/**
 * SMAP LogParser:: implementation.
 *
 * $Horde: odin/lib/LogParser/smap.php,v 1.2 2004/05/23 17:09:25 jan Exp $
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @version $Revision: 1.2 $
 * @access  public
 * @since   Odin 0.0.2
 * @package Odin
 */
class LogParser_smap extends LogParser {

    /**
     * Constructs a new LogParser_smap object.
     *
     * @access public
     */
    function LogParser_smap()
    {
    }

    /**
     * Parses log file.
     *
     * @access public
     * @param string $filename Filename to parse.
     * @returns mixed PEAR_Error class on failure, or true otherwise.
     */
    function parseFile($logfile)
    {
        if (!@file_exists($logfile)) {
            exit("Logfile '" . $logfile . "' does not exist.\n");
        }

        $incidents = array();

        $fp = @fopen($logfile, 'r');
        if (!$fp) {
            exit("Unable to open logfile '" . $logfile . "'.\n");
        }

        echo "Processing $logfile...\n";
        while ($line = fgets($fp, 4096)) {
            trim($line);
            if (!preg_match('/(\w{3}) +(\w{1,2}) (\d{2}:\d{2}:\d{2}) (\w+) (smap\w*)\[(\d+)\]: (.*)/', $line, $matches)) {
                continue;
            }

            list($whole, $month, $day, $timestamp, $host, $daemon, $pid, $msg) = $matches;

            $incidents[$pid]['date'] = sprintf('%04d%02d%02d', date('Y'), monthFromString($month), $day);
            $incidents[$pid]['time'] = $timestamp;
            $incidents[$pid]['smaphost'] = $host;

            if (strstr($msg, 'Rejected')) {
                $incidents[$pid]['rejected'] = 'yes';

                preg_match('/Rule: (.+?) {2}?(\S+) (.+)/', $msg, $matches);

                $incidents[$pid]['rule'] = $matches[1];
                $incidents[$pid]['pattern'] = $matches[3];
                $type = $matches[2];
                $type = str_replace(':', '', $type);
                $type = preg_replace('/([A-Z]+)/', '\l$1', $type);

                $incidents[$pid]['type'] = $type;
            } elseif (substr($msg, 0, 5) == 'host=' &&
                      preg_match('/^host=(.*) bytes=.* from=(.*) to=(.*)/', $msg, $matches)) {
                $incidents[$pid]['matches'] = $matches;

                $fromhost = $matches[1];
                $from = $matches[2];
                $to = $matches[3];

                $from = preg_replace('/[<,>]/', '', $from);
                $to = preg_replace('/[<,>]/', '', $to);

                $incidents[$pid]['fromhost'] = $fromhost;
                $incidents[$pid]['from'] = $from;
                $incidents[$pid]['to'] = $to;
            }
        }
    }

}
