<?php
/**
 * The Odin_Object:: class provides an interface for Odin objects -
 * people, groups, restaurants, etc.
 *
 * $Horde: odin/lib/Object.php,v 1.4 2004/05/23 17:09:24 jan Exp $
 *
 * @author  Chuck Hagenbuch <chuck@horde.org>
 * @author  Jon Parise <jon@csh.rit.edu>
 * @version $Revision: 1.4 $
 * @since   Odin 0.0.1
 * @package Odin
 */
class Odin_Object {

    /** Underlying instance of Odin_Source. */
    var $source;

    /** Hash of attributes for this contact. */
    var $attributes;


    /**
     * Constructs a new Odin_Object object.
     *
     * @param Odin_Source $source  The source that this object came from.
     * @param array $attributes     (optional) Hash of attributes for this contact.
     */
    function Odin_Object(&$source, $attributes = array())
    {
        $this->source = &$source;
        $this->attributes = $attributes;
    }

    /**
     * Returns a key-value hash containing all properties of this
     * object.
     *
     * @return array All properties of this object.
     */
    function getAttributes()
    {
        return $this->attributes;
    }

    /**
     * Returns the value of the specified attribute.
     *
     * @param string $attribute    The attribute to retrieve.
     *
     * @return string              The value of $attribute, or the empty string.
     */
    function getValue($attribute)
    {
        return (isset($this->attributes[$attribute]) ? $this->attributes[$attribute] : '');
    }

    /**
     * Sets the value of the specified attribute.
     *
     * @param $attribute    The attribute to set.
     */
    function setValue($attribute, $value)
    {
        $this->attributes[$attribute] = $value;
    }

    /**
     * Determines whether or not the object has a value for the specified attribute.
     *
     * @param $attribute    The attribute to check.
     *
     * @return boolean $has Whether or not there is a value for
     *                      $attribute.
     */
    function hasValue($attribute)
    {
        return (!empty($this->attributes[$attribute]));
    }

    /**
     * Returns true if this object is editable by the current user.
     *
     * @return boolean Whether or not the current user can edit this object
     */
    function isEditable()
    {
        global $conf;
        if (in_array(Auth::getAuth(), $conf['auth']['admins'])) {
            return true;
        }

        return false;
    }

    /**
     * Save the current state of the object to the storage backend.
     */
    function store()
    {
        return $this->source->setObject($this);
    }

}
