<?php

/** @const ODIN_SEARCH_AND. Boolean 'and' search. */ define('ODIN_SEARCH_AND', 100);
/** @const ODIN_SEARCH_OR Boolean 'or' search.    */ define('ODIN_SEARCH_OR', 101);
/** @const ODIN_DELETE Delete object.             */ define('ODIN_DELETE', 102);
/** @const ODIN_ADD Add object to a source.       */ define('ODIN_ADD', 103);
define('IMPORT_PROJECTS', 104);

/**
 * Odin Base Class.
 *
 * $Horde: odin/lib/Odin.php,v 1.14 2004/11/22 03:40:45 chuck Exp $
 *
 * @author Chuck Hagenbuch <chuck@horde.org>
 * @author Jon Parise <jon@horde.org>
 * @version $Revision: 1.14 $
 * @package Odin
 */
class Odin {

    function string2Columns($string)
    {
        $ret = array();
        $lines = explode("\n", $string);
        foreach ($lines as $line) {
            $line = trim($line);
            if (!empty($line)) {
                $columns = explode("\t", $line);
                if (count($columns) > 1) {
                    $source = array_splice($columns, 0, 1);
                    $ret[$source[0]] = $columns;
                }
            }
        }

        return $ret;
    }

    function columns2String($hash)
    {
        foreach ($hash as $source => $columns) {
            if (isset($string)) {
                $string .= "\n";
            } else {
                $string = '';
            }
            $line = '';
            foreach ($columns as $column) {
                if (!empty($line)) {
                    $line .= "\t";
                }
                $line .= $column;
            }
        }

        return $string;
    }

    /**
     * Generates the HTML for a day selection widget.
     *
     * @param string $name         The name of the widget.
     * @param int    $timestamp    (optional) The timestamp to select by default.
     * @param string $javascript   (optional) Any onchange, onblur, etc. javascript to include.
     *
     * @return string       The HTML <select> widget.
     */
    function buildDayWidget($name, $timestamp = null, $javascript = null)
    {
        $selected = (isset($timestamp) && ($timestamp != 0)) ? date('d', $timestamp) : null;

        $html = "<select name=\"$name\"";
        if ($javascript != null) {
            $html .= ' ' . $javascript;
        }
        $html .= '>';
        $html .= '<option value="">' . _("[Day]") . '</option>';
        for ($day = 1; $day <= 31; $day++) {
            $html .= "<option value=\"$day\"";
            $html .= ($day == $selected) ? ' selected="selected">' : '>';
            $html .= "$day</option>";
        }
        $html .= "</select>\n";

        return $html;
    }

    /**
     * Generates the HTML for a month selection widget.
     *
     * @param string $name         The name of the widget.
     * @param int    $timestamp    (optional) The timestamp to select by default.
     * @param string $javascript   (optional) Any onchange, onblur, etc. javascript to include.
     *
     * @return string       The HTML <select> widget.
     */
    function buildMonthWidget($name, $timestamp = null, $javascript = null)
    {
        $selected = (isset($timestamp) && ($timestamp != 0)) ? date('m', $timestamp) : null;

        $html = "<select name=\"$name\"";
        if ($javascript != null) {
            $html .= ' ' . $javascript;
        }
        $html .= '>';
        $html .= '<option value="">' . _("[Month]") . '</option>';
        for ($month = 1; $month <= 12; $month++) {
            $html .= "<option value=\"$month\"";
            $html .= ($month == $selected) ? ' selected="selected">' : '>';
            $html .= strftime('%B', mktime(0, 0, 0, $month)) . '</option>';
        }
        $html .= "</select>\n";

        return $html;
    }

    /**
     * Generates the HTML for an hour selection widget.
     *
     * @param string $name         The name of the widget.
     * @param int    $timestamp    (optional) The timestamp to select by default.
     * @param string $javascript   (optional) Any onchange, onblur, etc. javascript to include.
     *
     * @return string       The HTML <select> widget.
     */
    function buildHourWidget($name, $timestamp = null, $javascript = null)
    {
        $selected = (!is_null($timestamp)) ? date('H', $timestamp) : null;

        $html = "<select name=\"$name\"";
        if ($javascript != null) {
            $html .= ' ' . $javascript;
        }
        $html .= '><option value="">' . _("[Hour]") . '</option>';
        for ($hour = 0; $hour <= 23; $hour++) {
            $html .= "<option value=\"$hour\"";
            $html .= ($hour === $selected) ? ' selected="selected">' : '>';
            $html .= sprintf("%02d", $hour) . '</option>';
        }
        $html .= "</select>\n";

        return $html;
    }

    /**
     * Generates the HTML for a minute selection widget.
     *
     * @param string   $name         The name of the widget.
     * @param integer  $increment    (optional) The increment between minutes.
     * @param integer  $timestamp    (optional) The timestamp to select by default.
     * @param string   $javascript   (optional) Any onchange, onblur, etc. javascript to include.
     *
     * @return string       The HTML <select> widget.
     */
    function buildMinuteWidget($name, $increment = 1, $timestamp = null, $javascript = null)
    {
        $selected = (isset($timestamp)) ? date('i', $timestamp) : null;

        $html = "<select name=\"$name\"";
        if ($javascript != null) {
            $html .= ' ' . $javascript;
        }
        $html .= '><option value="">' . _("[Min]") . '</option>';
        for ($minute = 0; $minute <= 60; $minute += $increment) {
            $html .= "<option value=\"$minute\"";
            $html .= ($minute === $selected) ? ' selected="selected">' : '>';
            $html .= sprintf("%02d", $minute) . '</option>';
        }
        $html .= "</select>\n";

        return $html;
    }

    function buildSecondWidget($name, $increment = 1, $timestamp = null, $javascript = null)
    {
        $selected = (isset($timestamp)) ? date('s', $timestamp) : null;

        $html = "<select name=\"$name\"";
        if ($javascript != null) {
            $html .= ' ' . $javascript;
        }
        $html .= '><option value="">' . _("[Sec]") . '</option>';
        for ($second = 0; $second <= 60; $second += $increment) {
            $html .= "<option value=\"$second\"";
            $html .= ($second === $selected) ? ' selected="selected">' : '>';
            $html .= sprintf("%02d", $second) . '</option>';
        }
        $html .= "</select>\n";

        return $html;
    }

    /**
     * Build Odin's list of menu items.
     *
     * @access public
     */
    function getMenu($returnType = 'object')
    {
        require_once 'Horde/Menu.php';

        $menu = &new Menu(HORDE_MENU_MASK_ALL);
        if (Auth::isAdmin()) {
            $menu->add(Horde::applicationUrl('addobject.php'), _("Add"), 'add.png');
        }

        $menu->add(Horde::applicationUrl('query.php'), _("Search"), 'search.png',
                   $GLOBALS['registry']->getImageDir('horde'), null, null, (strpos($_SERVER['PHP_SELF'], 'query') === false || Util::getGet('advanced')) ? '__noselection' : null);
        $menu->add(Horde::applicationUrl('query.php?advanced=1'), _("Advanced"), 'search.png',
                   $GLOBALS['registry']->getImageDir('horde'), null, null, (!Util::getGet('advanced') ? '__noselection' : null));

        $menu->add(Horde::applicationUrl('summary.php'), _("Summary"), 'summary.png');
        $menu->add(Horde::applicationUrl('quicksearch.php'), _("QuickSearch"), 'quicksearch.png');
        $menu->add(Horde::applicationUrl('bydate.php'), _("By Date"), 'bydate.png');

        /* Import/Export. */
        if (($GLOBALS['conf']['menu']['import_export']) && Auth::isAdmin()) {
            $menu->add(Horde::applicationUrl('data.php'), _("Import/Export"), 'data.png', $GLOBALS['registry']->getImageDir('horde'));
        }

        if ($returnType == 'object') {
            return $menu;
        } else {
            return $menu->render();
        }
    }

}
